<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Foundation\Auth\SendsPasswordResetEmails;
use Illuminate\Http\Request;
use App\User;
use DB;
use Auth;

class ForgotPasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Password Reset Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling password reset emails and
    | includes a trait which assists in sending these notifications from
    | your application to your users. Feel free to explore this trait.
    |
    */

    use SendsPasswordResetEmails;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    public function verify_user(Request $Request)
    {
        $this->validate($Request, [
            
            'email' => ['required', 'string', 'email', 'max:255']

        ]);

        $email = $Request->get('email');
        $users = User::where('email', $email)->first();
        
        if(!$users){
            return back()->withErrors(['email' => [config('logging.EMAIL_NOT_FOUND')]]);            
        }

        //Generate otp with 4 characters
        $otp = mt_rand(1000,9999);
        $users->otp = $otp;
        $users->save();
        $details = [
        'otp'=>$otp
        ];
   
    //Sending email to users email for OTP
    \Mail::to($users->email)->send(new \App\Mail\email($details));

        return redirect()->route('reset_password',['user_id' => $users->id])->with('status', config('logging.CHECK_OTP_EMAIL'));
            
    }


    public function reset_password($value=''){
     
        return view('auth.passwords.reset');

    }

    public function update_password(Request $Request){
        

        $this->validate($Request, [
            
            'password' => ['required', 'string', 'min:8'],
            'confirm_password' => 'required|same:password|min:6',
            'otp'=>'required'

        ]);
       
        $user_id = $Request->get('user_id');
        $otp = $Request->get('otp');
        $password = $Request->get('password');
        
        $users = User::find($user_id);
        if(!$users){
            return back()->withErrors(['password' => [config('logging.USER_NOT_FOUND')]]);
        }

        if($users->otp == $otp){
            $users->password = bcrypt($password);
            $users->save();
            return redirect()->route('login')->with('status', config('logging.PASSWORD_CHANGED'));
        }
        return back()->withErrors(['password' => [config('logging.INVALID_OTP')]]);
    }
}

