<?php

namespace App\Http\Controllers;

use App\BookingRequests;
use DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;
use Carbon;

class BookingRequestsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
 

        $lkp_cartypes = DB::select('SELECT id,carName from lkp_cartypes order by carName');
        $lkp_paymenttype = DB::select('SELECT id,paymentType from lkp_paymenttype order by paymentType');
        $lkp_requestridestatus = DB::select('SELECT id,rideStatus from lkp_requestridestatus order by id');
        $Select_db = DB::table('booking_requests')
            ->select('booking_requests.id as id', DB::raw("IFNULL(notifications,'') as notifications"),
                'passengerId', 'name', 'carName', 'pickupAddress', 'destinationAddress',
                'pickupLatLong', 'destinationLatLong', 'estimatedPrice', 'estimatedDistance', 'estimatedTime',
                'paymentTypeId', 'paymentType', 'rideStatusId', 'rideStatus', 'booking_requests.created_at')
            ->leftJoin('passengers', 'booking_requests.passengerId', '=', 'passengers.id')
            ->leftJoin('lkp_cartypes', 'booking_requests.carTypeId', '=', 'lkp_cartypes.id')
            ->leftJoin('lkp_paymenttype', 'booking_requests.paymentTypeId', '=', 'lkp_paymenttype.id')
            ->leftJoin('lkp_requestridestatus', 'booking_requests.rideStatusId', '=', 'lkp_requestridestatus.id')
            ->leftJoin(DB::raw('(select requestId,count(*) as notifications from booking_request_notification
                  group by requestId
                  )request_notification'),
                'request_notification.requestId', '=', 'booking_requests.id')
            ->where('booking_requests.companyId', Auth::user()->companyId);
        if (request()->ajax()) {
            if (!empty($request->filter_passengerId)) {
                $Select_db->where('passengerId', $request->filter_passengerId);
            }
            if (!empty($request->filter_carTypeId)) {
                $Select_db->where('carTypeId', $request->filter_carTypeId);
            }
            if (!empty($request->filter_pickupAddress)) {
                $Select_db->whereRaw("UPPER(pickupAddress) LIKE '%".strtoupper($request->filter_pickupAddress)."%'");
            }
            if (!empty($request->filter_destinationAddress)) {
                $Select_db->whereRaw("UPPER(destinationAddress) LIKE '%".strtoupper($request->filter_destinationAddress)."%'");
            }
            if (!empty($request->filter_pickupLatLong)) {
                $Select_db->whereRaw("UPPER(pickupLatLong) LIKE '%".strtoupper($request->filter_pickupLatLong)."%'");
            }
            if (!empty($request->filter_destinationLatLong)) {
                $Select_db->whereRaw("UPPER(destinationLatLong) LIKE '%".strtoupper($request->filter_destinationLatLong)."%'");
            }
            if (!empty($request->filter_estimatedPrice)) {
                $Select_db->whereRaw("UPPER(estimatedPrice) LIKE '%".strtoupper($request->filter_estimatedPrice)."%'");
            }
            if (!empty($request->filter_estimatedDistance)) {
                $Select_db->whereRaw("UPPER(estimatedDistance) LIKE '%".strtoupper($request->filter_estimatedDistance)."%'");
            }
            if (!empty($request->filter_estimatedTime)) {
                $Select_db->whereRaw("UPPER(estimatedTime) LIKE '%".strtoupper($request->filter_estimatedTime)."%'");
            }
            if (!empty($request->filter_paymentTypeId)) {
                $Select_db->where(';', $request->filter_paymentTypeId);
            }
            if (!empty($request->filter_rideStatusId)) {
                $Select_db->where('rideStatusId', $request->filter_rideStatusId);
            }
            if (!empty($request->filter_created_at)) {
                $filter_created_at = explode(" to ", $request->filter_created_at);

                $filter_created_at[0] = Carbon\Carbon::parse($filter_created_at[0])->format('Y-m-d');
                $filter_created_at[1] = Carbon\Carbon::parse($filter_created_at[1])->format('Y-m-d');
              //  $Select_db->whereRaw("CAST(created_at as date) between STR_TO_DATE('$filter_created_at[0]','%d/%m/%Y') and STR_TO_DATE('$filter_created_at[1]','%d/%m/%Y')");
                $Select_db->whereRaw("booking_requests.created_at between '$filter_created_at[0]' and '$filter_created_at[1]' ");
            }
            if (!empty($request->filter_updated_at)) {
                $filter_updated_at = explode(" to ", $request->filter_updated_at);
                $filter_updated_at[0] = Carbon\Carbon::parse($filter_updated_at[0])->format('Y-m-d');
                $filter_updated_at[1] = Carbon\Carbon::parse($filter_updated_at[1])->format('Y-m-d');
                $Select_db->whereRaw("booking_requests.updated_at between '$filter_created_at[0]' and '$filter_created_at[1]'");
            }
            $data = $Select_db->get();
            return datatables()->of($data)->make(true);
        }
        $data = $Select_db->get();
//$BookingRequests = BookingRequests::orderBy('created_at', 'desc')->paginate(10);
        return view('BookingRequests.index')->with(compact('lkp_cartypes'))->with(compact('lkp_paymenttype'))->with(compact('lkp_requestridestatus'));
//return view('custom_search', compact('country_name'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {


//return $id;
        $BookingRequests = DB::table('booking_requests')
            ->select('booking_requests.id as id', DB::raw("IFNULL(notifications,'') as notifications"), 'name',
                'carName', 'pickupAddress', 'destinationAddress',
                'pickupLatLong', 'destinationLatLong', 'estimatedPrice', 'estimatedDistance', 'estimatedTime',
                'paymentType', 'rideStatus', 'booking_requests.created_at', 'booking_requests.updated_at')
            ->leftJoin('passengers', 'booking_requests.passengerId', '=', 'passengers.id')
            ->leftJoin('lkp_cartypes', 'booking_requests.carTypeId', '=', 'lkp_cartypes.id')
            ->leftJoin('lkp_paymenttype', 'booking_requests.paymentTypeId', '=', 'lkp_paymenttype.id')
            ->leftJoin('lkp_requestridestatus', 'booking_requests.rideStatusId', '=', 'lkp_requestridestatus.id')
            ->leftJoin(DB::raw('(select requestId,count(*) as notifications from booking_request_notification
                  group by requestId
                  )request_notification'),
                'request_notification.requestId', '=', 'booking_requests.id')
            ->where('booking_requests.companyId', Auth::user()->companyId)
            ->where('booking_requests.id', $id)
            ->first();
        return view('BookingRequests.show')->with(compact('BookingRequests'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
    }

    public function RequestNotifications($id)
    {
        $BookingRequest = DB::select("select booking_requests.created_at,bookings.created_at as created_at2 from booking_requests
left join bookings on bookings.requestId=booking_requests.id
where booking_requests.id=".$id)[0];
        $RequestNotifications = DB::select("select
name,booking_request_notification.created_at,max_created_at,
booking_request_notification.driverId as driverId1,bookings.driverId as driverId2,bookings.created_at as created_at2
from booking_request_notification
inner join drivers on drivers.id=booking_request_notification.driverId
left join bookings on bookings.requestId=booking_request_notification.requestId
left JOIN
(
SELECT driverId, MAX(created_at) AS max_created_at
FROM booking_request_notification
where requestId=".$id." and created_at<='".$BookingRequest->created_at2."'
GROUP BY driverId
) t2
ON booking_request_notification.driverId = t2.driverId
where booking_request_notification.companyId=".Auth::user()->companyId."
and booking_request_notification.requestId=".$id." order by booking_request_notification.created_at");
        return view('BookingRequests.RequestNotifications')->with(compact('BookingRequest'))->with(compact('RequestNotifications'));
    }

    public function getBookingDetails($id)
    {
         $BookingRequests = DB::table('bookings')
            ->select('bookings.id as id',
                'pickupAddress', 'destinationAddress',
                'pickupLatLong', 'destinationLatLong', 'estimatedPrice', 'estimatedDistance', 'estimatedTime',
                 'rideStatus', 'bookings.created_at', 'bookings.updated_at', 'passengers.id as passenger_id', 'passengers.name as passenger_name', 'passengers.mobile  as passenger_mobile')
            ->leftJoin('passengers', 'bookings.passengerId', '=', 'passengers.id')
            ->leftJoin('lkp_requestridestatus', 'bookings.rideStatusId', '=', 'lkp_requestridestatus.id')
            
            
            ->where('bookings.id', $id)->first();
            return response()->json($BookingRequests);
    }


    public function driverTracking($page){

        if(!UserAccessController::check_access(14, 'read')){
           return redirect('/no_access');
        }

            $BookingRequests  = $this->bookingDetails($query="", $page);
            $BookingRequests->page = $page;

            
            return view('Tracking.driverTracking')->with(compact('BookingRequests'));
    }

    public function get_bookings(Request $request)
    {
        $query = $request->input('query');
        $BookingRequests  = $this->bookingDetails($query);
        $data = array('suggestions'=>$BookingRequests);

        return response()->json($data);
    }


    public function get_paginate_bookings($page)
    {
       
        
        $BookingRequests  = $this->bookingDetails("", $page);


        //$html=view('slider')->with(compact('BookingRequests'));
        //$data = array(0=>$html);
        return view('slider')->with(compact('BookingRequests'));
    }

        public function get_booking_by_id($id)
    {
       
        
            $BookingRequests = DB::table('bookings')->select('bookings.id as id', 'bookings.id as data', 'requestId', 'passengerId',
            'passengers.name as passenger_name',DB::raw('CONCAT("Booking# ", bookings.id) AS value'), 'passengers.profileImage as passenger_profile',
            'bookings.driverId as driverId', 'drivers.name as driver_name',
            'carName', 'pickupAddress', 'destinationAddress', 'pickupLatLong', 'destinationLatLong', 'endTripLatLng',
            'finalTripCost', 'totalPay', 'finalDistance', 'waitingTime', 'finalTime', 'rideStartDateTime',
            'rideEndDateTime',
            'paymentTypeId', 'paymentType', 'bookings.rideStatusId', 'rideStatus', 'vehichleId',
            'tripReferenceNumber', 'bookings.created_at', 'bookings.updated_at')
            ->leftJoin('passengers', 'bookings.passengerId', '=', 'passengers.id')
            ->leftJoin('lkp_cartypes', 'bookings.carTypeId', '=', 'lkp_cartypes.id')
            ->leftJoin('lkp_paymenttype', 'bookings.paymentTypeId', '=', 'lkp_paymenttype.id')
            ->leftJoin('lkp_ridestatus', 'bookings.rideStatusId', '=', 'lkp_ridestatus.id')
            ->leftJoin('drivers', 'bookings.driverId', '=', 'drivers.id')
            ->leftJoin('driver_vehicles', 'bookings.vehichleId', '=', 'driver_vehicles.id')             
            ->where('bookings.companyId', Auth::user()->companyId)->where('bookings.id', $id);
            $BookingRequests = $BookingRequests->paginate(4,['*'],'page',1)->chunk(1);

            
        return view('slider')->with(compact('BookingRequests'));
    }




    public function bookingDetails($query = "", $page=1){


        $BookingRequests = DB::table('bookings')->select('bookings.id as id', 'bookings.id as data', 'requestId', 'passengerId',
            'passengers.name as passenger_name',DB::raw('CONCAT("Booking# ", bookings.id) AS value'), 'passengers.profileImage as passenger_profile',
            'bookings.driverId as driverId', 'drivers.name as driver_name',
            'carName', 'pickupAddress', 'destinationAddress', 'pickupLatLong', 'destinationLatLong', 'endTripLatLng',
            'finalTripCost', 'totalPay', 'finalDistance', 'waitingTime', 'finalTime', 'rideStartDateTime',
            'rideEndDateTime',
            'paymentTypeId', 'paymentType', 'bookings.rideStatusId', 'rideStatus', 'vehichleId',
            'tripReferenceNumber', 'bookings.created_at', 'bookings.updated_at')
            ->leftJoin('passengers', 'bookings.passengerId', '=', 'passengers.id')
            ->leftJoin('lkp_cartypes', 'bookings.carTypeId', '=', 'lkp_cartypes.id')
            ->leftJoin('lkp_paymenttype', 'bookings.paymentTypeId', '=', 'lkp_paymenttype.id')
            ->leftJoin('lkp_ridestatus', 'bookings.rideStatusId', '=', 'lkp_ridestatus.id')
            ->leftJoin('drivers', 'bookings.driverId', '=', 'drivers.id')
            ->leftJoin('driver_vehicles', 'bookings.vehichleId', '=', 'driver_vehicles.id')             
            ->where('bookings.companyId', Auth::user()->companyId);

        if($query !=""){
            $BookingRequests->Where('bookings.id','like',"%{$query}%");
            return $BookingRequests->get();

        }

        return $BookingRequests->paginate(4,['*'],'page',$page)->chunk(4);
        //return $BookingRequests->get()->chunk(4);

    }

}
