<?php

namespace App\Http\Controllers;

use App\Drivers;
use DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;
use Carbon;
use File;

class DriversController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if(!UserAccessController::check_access(8, 'read')){
           return redirect('/no_access');
        }

        //dd($request->all());
        $countries = DB::select('SELECT id,country_en from lkp_country order by country_en');
        $driverstatus = DB::select('SELECT id,status from lkp_driverstatus order by id');
        $users = DB::select('SELECT id,name from users order by name');

        $Select_db = DB::table('drivers')
            ->select('drivers.id as id', 'drivers.name', 'mobileNumber', 'loginStatusId', 'driverStatusId',
                'lkp_driverstatus.status', 'rating', 'completeTrips', 'cancelledTrips', 'validityId', 'validity_dt',
                'users.name as validity_by_name',
                'lkp_validity.status as validity_name', 'drivers.created_at', 'drivers.updated_at')
            ->leftJoin('lkp_driverstatus', 'drivers.driverStatusId', '=', 'lkp_driverstatus.id')
            ->leftJoin('lkp_validity', 'drivers.validityId', '=', 'lkp_validity.id')
            ->leftJoin('users', 'drivers.validity_by_id', '=', 'users.id')
            ->where('drivers.companyId', Auth::user()->companyId);

        if (request()->ajax()) {

            if (!empty($request->filter_name)) {
                $Select_db->whereRaw("UPPER(drivers.name) LIKE '%".strtoupper($request->filter_name)."%'");
            }
            if (!empty($request->filter_mobileNumber)) {
                $Select_db->whereRaw("UPPER(mobileNumber) LIKE '%".strtoupper($request->filter_mobileNumber)."%'");
            }
            if (!empty($request->filter_emailAddress)) {
                $Select_db->whereRaw("UPPER(emailAddress) LIKE '%".strtoupper($request->filter_emailAddress)."%'");
            }
            if (!empty($request->filter_dateOfBirthHijri)) {
                $filter_dateOfBirthHijri = explode(" to ", $request->filter_dateOfBirthHijri);
                $Select_db->whereRaw("CAST(dateOfBirthHijri as date) between STR_TO_DATE('$filter_dateOfBirthHijri[0]','%d/%m/%Y') and STR_TO_DATE('$filter_dateOfBirthHijri[1]','%d/%m/%Y')");
            }
            if (!empty($request->filter_dateOfBirthGregorian)) {
                $filter_dateOfBirthGregorian = explode(" to ", $request->filter_dateOfBirthGregorian);
                $Select_db->whereRaw("CAST(dateOfBirthGregorian as date) between STR_TO_DATE('$filter_dateOfBirthGregorian[0]','%d/%m/%Y') and STR_TO_DATE('$filter_dateOfBirthGregorian[1]','%d/%m/%Y')");
            }
            if (!empty($request->filter_nationalityId)) {
                $Select_db->where('nationalityId', $request->filter_nationalityId);
            }
            if (!empty($request->filter_identityNumber)) {
                $Select_db->whereRaw("UPPER(identityNumber) LIKE '%".strtoupper($request->filter_identityNumber)."%'");
            }
            if (!empty($request->filter_eligibilityExpiryDate)) {
                $filter_eligibilityExpiryDate = explode(" to ", $request->filter_eligibilityExpiryDate);
                $Select_db->whereRaw("CAST(eligibilityExpiryDate as date) between STR_TO_DATE('$filter_eligibilityExpiryDate[0]','%d/%m/%Y') and STR_TO_DATE('$filter_eligibilityExpiryDate[1]','%d/%m/%Y')");
            }
            if (!empty($request->filter_driverStatusId)) {
                $Select_db->where('driverStatusId', $request->filter_driverStatusId);
            }
            if (!empty($request->filter_gender)) {
                $Select_db->where('genderId', $request->filter_gender);
            }
            if (!empty($request->filter_address)) {
                $Select_db->whereRaw("UPPER(address) LIKE '%".strtoupper($request->filter_address)."%'");
            }
            if (!empty($request->filter_rating)) {
                $Select_db->where('rating', $request->filter_rating);
            }
            if (!empty($request->filter_loginStatus)) {
                $Select_db->where('loginStatusId', $request->filter_loginStatus);
            }
            if (!empty($request->filter_completeTrips)) {
                $Select_db->where('completeTrips', $request->filter_completeTrips);
            }
            if (!empty($request->filter_cancelledTrips)) {
                $Select_db->where('cancelledTrips', $request->filter_cancelledTrips);
            }
            if (!empty($request->filter_validity)) {
                $Select_db->where('validityId', $request->filter_validity);
            }
            if (!empty($request->filter_validity_dt)) {
                $filter_validity_dt = explode(" to ", $request->filter_validity_dt);
                $Select_db->whereRaw("CAST(drivers.validity_dt as date) between STR_TO_DATE('$filter_validity_dt[0]','%d/%m/%Y') and STR_TO_DATE('$filter_validity_dt[1]','%d/%m/%Y')");
            }
            if (!empty($request->filter_validity_by_id)) {
                $Select_db->where('validity_by_id', $request->filter_validity_by_id);
            }
            if (!empty($request->filter_created_at)) {
                $filter_created_at = explode(" to ", $request->filter_created_at);
                $Select_db->whereRaw("CAST(drivers.created_at as date) between STR_TO_DATE('$filter_created_at[0]','%d/%m/%Y') and STR_TO_DATE('$filter_created_at[1]','%d/%m/%Y')");
            }
            if (!empty($request->filter_updated_at)) {
                $filter_updated_at = explode(" to ", $request->filter_updated_at);
                $Select_db->whereRaw("CAST(drivers.updated_at as date) between STR_TO_DATE('$filter_updated_at[0]','%d/%m/%Y') and STR_TO_DATE('$filter_updated_at[1]','%d/%m/%Y')");
            }


            $data = $Select_db->get();
            return datatables()->of($data)->make(true);
        }

        $data = $Select_db->get();
        //$Drivers = Drivers::orderBy('created_at', 'desc')->paginate(10);
        return view('Drivers.index')->with(compact('countries'))
            ->with(compact('driverstatus'))->with(compact('users'));
        //return view('custom_search', compact('country_name'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(!UserAccessController::check_access(9, 'write')){
           return redirect('/no_access');
        }

        $countries = DB::select('SELECT id,country_en from lkp_country order by country_en');
        $driverstatus = DB::select('SELECT id,status from lkp_driverstatus order by id');
        return view('Drivers.create')->with(compact('countries'))->with(compact('driverstatus'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        //
        $this->validate($request, [
             'name' => ['required', 'string', 'max:255'],
             'emailAddress' => ['required', 'string', 'email', 'max:255', 'unique:drivers'],
             //'password' => ['required', 'string', 'min:8', 'confirmed'],

         ]);
        

        $Drivers = new Drivers;
        $picture = null;
        $Drivers->name = $request->input('name');
        $Drivers->lname = $request->input('lname');
        $Drivers->genderId = $request->input('genderId');
        $Drivers->emailAddress = $request->input('emailAddress');
        $Drivers->mobileNumber = $request->input('mobileNumber');
        $Drivers->nationalityId = $request->input('nationalityId');
        //$Drivers->ProfileImage = $request->input('ProfileImage');
        $Drivers->dateOfBirthHijri = (empty($request->input('dateOfBirthHijri'))) ? null : Carbon\Carbon::parse($request->input('dateOfBirthHijri'))->format('Y-m-d');
        $Drivers->dateOfBirthGregorian = (empty($request->input('dateOfBirthGregorian'))) ? null : Carbon\Carbon::parse($request->input('dateOfBirthGregorian'))->format('Y-m-d');
        $Drivers->identityNumber = $request->input('identityNumber');
        $Drivers->eligibilityExpiryDate = (empty($request->input('eligibilityExpiryDate'))) ? null : Carbon\Carbon::parse($request->input('eligibilityExpiryDate'))->format('Y-m-d');
        $Drivers->driverStatusId = $request->input('driverStatusId');
        $Drivers->loginStatusId = $request->input('loginStatusId');
        $Drivers->address = empty($request->input('address')) ? null : $request->input('address');
        $Drivers->deviceType = 2;
        $Drivers->validityId = $request->input('validityId');
        $Drivers->validity_dt = date("Y-m-d H:i:s");
        $Drivers->validity_by_id = Auth::user()->id;
        $Drivers->companyId = Auth::user()->companyId;

                if ($request->hasFile('ProfileImage')) {
    
                $file      = $request->file('ProfileImage');
                $filename  = $file->getClientOriginalName();
                $extension = $file->getClientOriginalExtension();
                $picture =  $filename.'_'.date('YmdHi').'.'.$extension;
                $file->move(public_path('driver_images'), $picture);
            }
        $Drivers->profileImage =  $picture;     
        $Drivers->save();

        return redirect('/Drivers')->with('success', 'Done successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(!UserAccessController::check_access(8, 'read')){
           return redirect('/no_access');
        }

        //return $id;
        $Select_db = DB::table('drivers')
            ->select('drivers.id as id', 'drivers.name', 'drivers.lname', 'mobileNumber', 'emailAddress', 'dateOfBirthHijri',
                'dateOfBirthGregorian', 'country_en', 'drivers.profileImage',
                'identityNumber', 'identityProofImage', 'licenseProofImage', 'eligibilityExpiryDate',
                'lkp_gender.gender as gender_name', 'address',
                'latLng', 'drivers.created_at', 'drivers.updated_at',
                'validity_dt', 'users.name as validity_by_name',
                'loginStatusId', 'lkp_login.status as loginStatus_name', 'driverStatusId', 'lkp_driverstatus.status',
                'rating', 'completeTrips', 'cancelledTrips', 'validityId', 'lkp_validity.status as validity_name',
                'totalTripFares', 'totalEarning', 'totalVatPaid', 'totalCompanyProfit', 'totalPay', 'currentEarning',
                'currentCompanyProfit', 'currentVat', 'credit', 'previousBalance')
            ->leftJoin('lkp_driverstatus', 'drivers.driverStatusId', '=', 'lkp_driverstatus.id')
            ->leftJoin('lkp_country', 'drivers.nationalityId', '=', 'lkp_country.id')
            ->leftJoin('lkp_validity', 'drivers.validityId', '=', 'lkp_validity.id')
            ->leftJoin('lkp_login', 'drivers.loginStatusId', '=', 'lkp_login.id')
            ->leftJoin('lkp_gender', 'drivers.genderId', '=', 'lkp_gender.id')
            ->leftJoin('driverwallet', 'drivers.id', '=', 'driverwallet.driverId')
            ->leftJoin('users', 'drivers.validity_by_id', '=', 'users.id')
            ->where('drivers.companyId', Auth::user()->companyId)
            ->where('drivers.id', $id);

        $Drivers = $Select_db->first();
        //$Drivers = Drivers::find($id);

        return view('Drivers.show')->with('Drivers', $Drivers);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(!UserAccessController::check_access(8, 'write')){
           return redirect('/no_access');
        }

        $countries = DB::select('SELECT id,country_en from lkp_country order by country_en');
        $driverstatus = DB::select('SELECT id,status from lkp_driverstatus order by id');
        $Drivers = Drivers::where('id', $id)->where('companyId', Auth::user()->companyId)->first();
        return view('Drivers.edit')->with(compact('Drivers'))->with(compact('countries'))->with(compact('driverstatus'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //'password' => ['required', 'string', 'min:8', 'confirmed'],
        /* $this->validate($request, [
             'name' => ['required', 'string', 'max:255'],
             'email' => ['required', 'string', 'email', 'max:255'],

         ]);
        */


        $Drivers = Drivers::where('id', $id)->where('companyId', Auth::user()->companyId)->first();
        $picture = null; 
        $Drivers->name = $request->input('name');
        $Drivers->lname = $request->input('lname');
        $Drivers->genderId = $request->input('genderId');
        $Drivers->emailAddress = $request->input('emailAddress');
        $Drivers->mobileNumber = $request->input('mobileNumber');
        $Drivers->nationalityId = $request->input('nationalityId');
        //$Drivers->ProfileImage = $request->input('ProfileImage');
        $Drivers->dateOfBirthHijri = (empty($request->input('dateOfBirthHijri'))) ? null : Carbon\Carbon::parse($request->input('dateOfBirthHijri'))->format('Y-m-d');
        $Drivers->dateOfBirthGregorian = (empty($request->input('dateOfBirthGregorian'))) ? null : Carbon\Carbon::parse($request->input('dateOfBirthGregorian'))->format('Y-m-d');
        $Drivers->identityNumber = $request->input('identityNumber');
      
        $Drivers->eligibilityExpiryDate = (empty($request->input('eligibilityExpiryDate'))) ? null : Carbon\Carbon::parse($request->input('eligibilityExpiryDate'))->format('Y-m-d');
        $Drivers->driverStatusId = $request->input('driverStatusId');
        $Drivers->loginStatusId = $request->input('loginStatusId');
        $Drivers->address = $request->input('address');

        if ($Drivers->validityId <> $request->input('validityId')) {
            $Drivers->validity_dt = date("Y-m-d H:i:s");
            $Drivers->validity_by_id = Auth::user()->id;
        }
        $Drivers->validityId = $request->input('validityId');

                        if ($request->hasFile('ProfileImage')) {
                                            //Remove existing image from file directory

        if(File::exists(public_path('driver_images/'.$Drivers->profileImage))){
            
            File::delete(public_path('driver_images/'.$Drivers->profileImage));
        }
    
                $file      = $request->file('ProfileImage');
                $filename  = $file->getClientOriginalName();
                $extension = $file->getClientOriginalExtension();
                $picture =  $filename.'_'.date('YmdHi').'.'.$extension;
                $file->move(public_path('driver_images'), $picture);
                $Drivers->ProfileImage =  $picture;   
            }


        $Drivers->save();

        return redirect('/Drivers')->with('success', 'Done successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(!UserAccessController::check_access(8, 'write')){
           return redirect('/no_access');
        }

        $Drivers = Drivers::where('id', $id)->where('companyId', Auth::user()->companyId)->first();
        // if(auth()->Drivers()->id !== $Drivers->Drivers_id){
        //    return redirect('/Drivers')->with('error','Unauthorized');
        // }

        if ($Drivers->logo != 'noImage.jpg') {
            Storage::delete('public/app/storage'.$Drivers->logo);

        }

        $Drivers->delete();

        return redirect('/Drivers')->with('success', 'Done successfully');
    }

    public function get_drivers(Request $request)
    {
        $query = $request->input('query');
        $drivers = DB::table('drivers')->select('id as data', 'name as value')->Where('name','like',"%{$query}%")->get();
        $data = array('suggestions'=>$drivers);

        return response()->json($data);
    }

        public function getdriversData($id)
    {
             $Drivers = DB::table('driver_vehicles')
            ->select('driver_vehicles.id as id', 'model', 'drivers.name', 'drivers.mobileNumber as mobile', 'driver_vehicles.colour', 'carName', 'lkp_carbrands.name_en as Brand_En',
                'lkp_carbrandsub.name_en as BrandSub_En', 'colour', 'sequenceNumber',
                'plateLetterRight', 'plateLetterMiddle', 'plateLetterLeft', 'plateNumber',
                'englishName', 'vehicleReferenceNumber', 'driver_vehicles.validityId',
                'driver_vehicles.validity_dt', 'users.name as validity_by_name',
                'lkp_validity.status as validity_status','driver_vehicles.created_at', 'driver_vehicles.updated_at')
            ->leftJoin('drivers', 'driver_vehicles.driverId', '=', 'drivers.id')
            ->leftJoin('lkp_cartypes', 'driver_vehicles.carTypeId', '=', 'lkp_cartypes.id')
            ->leftJoin('lkp_carbrands', 'driver_vehicles.carbrand_Id', '=', 'lkp_carbrands.id')
            ->leftJoin('lkp_carbrandsub', 'driver_vehicles.carbrandsub_Id', '=', 'lkp_carbrandsub.id')
            ->leftJoin('lkp_vehicleplatetype', 'driver_vehicles.plateTypeId', '=', 'lkp_vehicleplatetype.id')
            ->leftJoin('lkp_validity', 'driver_vehicles.validityId', '=', 'lkp_validity.id')
            ->leftJoin('users', 'driver_vehicles.validity_by_id', '=', 'users.id')
            
            ->where('drivers.id', $id)->first();

            
        return response()->json($Drivers);

    }

    public function heatMap(){
        if(!UserAccessController::check_access(15, 'read')){
           return redirect('/no_access');
        }

        return view('Tracking.heat');
    }

    public function getHeatCoordinates(){
            
             $map = DB::table('heatmap')->get();
             return response()->json($map);
    }
    

    
}
