<?php

namespace App\Http\Controllers;

//use App\Orders;
use DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;
use Carbon;

class OrdersController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

        if(!UserAccessController::check_access(20, 'read')){
           return redirect('/no_access');
        }

        $lkp_cartypes = DB::select('SELECT id,carName from lkp_cartypes order by carName');
        $lkp_paymenttype = DB::select('SELECT id,paymentType from lkp_paymenttype order by paymentType');
        $lkp_order_status = DB::select('SELECT id,status from lkp_order_status order by id');


        $Select_db = DB::table('orders')->select('orders.id as id', 'customerId',
            'passengers.name as passenger_name',
            'orders.driverId as driverId', 'drivers.name as driver_name',
            'carName', 'pickupAddress', 'dropoffAddress', 'pickupLatLong', 'dropoffLatLong',
            'minimumPrice', 'minimumPrice', 'totalDistance', 'estimatedDistance', 'totalTime', 'orderPickedupDateTime',
            'orderDeliveredDateTime',
            'paymentTypeId', 'paymentType', 'orders.orderStatusId', 'lkp_order_status.status', 'vehicleId',
            'orderDetail', 'orders.created_at', 'orders.updated_at')
            ->leftJoin('passengers', 'orders.customerId', '=', 'passengers.id')
            ->leftJoin('lkp_cartypes', 'orders.carTypeId', '=', 'lkp_cartypes.id')
            ->leftJoin('lkp_paymenttype', 'orders.paymentTypeId', '=', 'lkp_paymenttype.id')
            ->leftJoin('lkp_order_status', 'orders.orderStatusId', '=', 'lkp_order_status.id')
            ->leftJoin('drivers', 'orders.driverId', '=', 'drivers.id')
            ->leftJoin('driver_vehicles', 'orders.vehicleId', '=', 'driver_vehicles.id')
            ;


        if (request()->ajax()) {

            if (!empty($request->filter_customerId)) {
                $Select_db->where('customerId', $request->filter_customerId);
            }
            if (!empty($request->filter_driverId)) {
                $Select_db->where('orders.driverId', $request->filter_driverId);
            }
            if (!empty($request->filter_vehicleId)) {
                $Select_db->where('orders.vehicleId', $request->filter_vehicleId);
            }
            if (!empty($request->filter_carTypeId)) {
                $Select_db->where('orders.carTypeId', $request->filter_carTypeId);
            }
            if (!empty($request->filter_pickupAddress)) {
                $Select_db->whereRaw("UPPER(orders.pickupAddress) LIKE '%".strtoupper($request->filter_pickupAddress)."%'");
            }
            if (!empty($request->filter_dropoffAddress)) {
                $Select_db->whereRaw("UPPER(orders.dropoffAddress) LIKE '%".strtoupper($request->filter_dropoffAddress)."%'");
            }
            if (!empty($request->filter_pickupLatLong)) {
                $Select_db->whereRaw("UPPER(orders.pickupLatLong) LIKE '%".strtoupper($request->filter_pickupLatLong)."%'");
            }
            if (!empty($request->filter_destinationLatLong)) {
                $Select_db->whereRaw("UPPER(destinationLatLong) LIKE '%".strtoupper($request->filter_destinationLatLong)."%'");
            }
            if (!empty($request->filter_minimumPrice)) {
                $Select_db->where('orders.minimumPrice', $request->filter_minimumPrice);
            }
            if (!empty($request->filter_minimumPrice)) {
                $Select_db->where('orders.minimumPrice', $request->filter_minimumPrice);
            }
            if (!empty($request->filter_totalDistance)) {
                $Select_db->where('orders.totalDistance', $request->filter_totalDistance);
            }
            if (!empty($request->filter_totalTime)) {
                $Select_db->where('orders.totalTime', $request->filter_totalTime);
            }
            if (!empty($request->filter_orderPickedupDateTime)) {
                $Select_db->where('orders.orderPickedupDateTime', $request->filter_orderPickedupDateTime);
            }
            if (!empty($request->filter_orderDeliveredDateTime)) {
                $Select_db->where('orders.orderDeliveredDateTime', $request->filter_orderDeliveredDateTime);
            }
            if (!empty($request->filter_paymentTypeId)) {
                $Select_db->where('orders.paymentTypeId', $request->filter_paymentTypeId);
            }
            if (!empty($request->filter_orderStatusId)) {
                $Select_db->where('orders.orderStatusId', $request->filter_orderStatusId);
            }
            if (!empty($request->filter_orderDetail)) {
                $Select_db->where('orders.orderDetail', $request->filter_orderDetail);
            }
            if (!empty($request->filter_estimatedDistance)) {
                $Select_db->where('orders.estimatedDistance', $request->filter_estimatedDistance);
            }

            if (!empty($request->filter_created_at)) {
                $filter_created_at = explode(" to ", $request->filter_created_at);
                $filter_created_at[0] = Carbon\Carbon::parse($filter_created_at[0])->format('Y-m-d');
                $filter_created_at[1] = Carbon\Carbon::parse($filter_created_at[1])->format('Y-m-d');
                //$Select_db->whereRaw("CAST(orders.created_at as date) between STR_TO_DATE('$filter_created_at[0]','%d/%m/%Y') and STR_TO_DATE('$filter_created_at[1]','%d/%m/%Y')");
                $Select_db->whereRaw("orders.created_at between '$filter_created_at[0]' and '$filter_created_at[1]' ");
            }
            if (!empty($request->filter_updated_at)) {
                $filter_updated_at = explode(" to ", $request->filter_updated_at);
                $filter_updated_at[0] = Carbon\Carbon::parse($filter_updated_at[0])->format('Y-m-d');
                $filter_updated_at[1] = Carbon\Carbon::parse($v[1])->format('Y-m-d');
                $Select_db->whereRaw("orders.updated_at between '$filter_updated_at[0]' and '$filter_updated_at[1]' ");
            }


            $data = $Select_db->get();
            return datatables()->of($data)->make(true);
        }

        $data = $Select_db->get();
        //$Orders = Orders::orderBy('created_at', 'desc')->paginate(10);
        return view('Orders.index')->with(compact('lkp_cartypes'))
            ->with(compact('lkp_paymenttype'))
            ->with(compact('lkp_order_status'));
        //return view('custom_search', compact('country_name'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {


    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {

        if(!UserAccessController::check_access(20, 'read')){
           return redirect('/no_access');
        }

        
        //return $id;

        $Orders = DB::table('orders')
            ->select('orders.id as id', 'customerId', 'passengers.name as passenger_name',
                'orders.driverId as driverId', 'drivers.name as driver_name',
                'carName', 'pickupAddress', 'dropoffAddress', 'pickupLatLong', 'dropoffLatLong',
                'dropoffLatLong',
                'minimumPrice', 'totalDistance', 'estimatedDistance', 'totalTime', 'orderPickedupDateTime',
                'orderDeliveredDateTime',
                'paymentTypeId', 'paymentType', 'orders.orderStatusId', 'lkp_order_status.status', 'vehicleId',
                'orderDetail', 'orders.created_at', 'orders.updated_at',
                'lkp_carbrands.name_en as Brand_En', 'lkp_carbrandsub.name_en as BrandSub_En', 'model', 'colour',
                'sequenceNumber','orderDetail',
                DB::raw("CONCAT(plateLetterRight,' ',plateLetterMiddle,' ',plateLetterLeft,' ',plateNumber )  AS plate"))
            ->leftJoin('passengers', 'orders.customerId', '=', 'passengers.id')
            ->leftJoin('lkp_cartypes', 'orders.carTypeId', '=', 'lkp_cartypes.id')
            ->leftJoin('lkp_paymenttype', 'orders.paymentTypeId', '=', 'lkp_paymenttype.id')
            ->leftJoin('lkp_order_status', 'orders.orderStatusId', '=', 'lkp_order_status.id')
            ->leftJoin('drivers', 'orders.driverId', '=', 'drivers.id')
            ->leftJoin('driver_vehicles', 'orders.vehicleId', '=', 'driver_vehicles.id')
            ->leftJoin('lkp_carbrands', 'driver_vehicles.carbrand_Id', '=', 'lkp_carbrands.id')
            ->leftJoin('lkp_carbrandsub', 'driver_vehicles.carbrandsub_Id', '=', 'lkp_carbrandsub.id')
            ->leftJoin('lkp_vehicleplatetype', 'driver_vehicles.plateTypeId', '=', 'lkp_vehicleplatetype.id')
            ->leftJoin('lkp_validity', 'driver_vehicles.validityId', '=', 'lkp_validity.id')
            ->where('orders.id', $id)
            ->first();
        return view('Orders.show')->with(compact('Orders'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {

    }

}
