<?php

namespace App\Http\Controllers;

use DB;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use File;
use App\Http\Middleware;
//use Illuminate\Support\Facades\DB;
use App\Http\Controllers\UserAccessController; 

class UsersController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

            
        if(!UserAccessController::check_access(2, 'read')){
           return redirect('/no_access');
        }
        


        $Select_db = DB::table('users')
            ->select('users.id as id', 'name', 'phone', 'email', 'active_id', 'active', 'role_id', 'role_name',
                'users.created_at', 'users.updated_at')
            ->leftJoin('lkp_active', 'users.active_id', '=', 'lkp_active.id')
            ->leftJoin('users_role', 'users.role_id', '=', 'users_role.id')
            ->where('users.companyId', Auth::user()->companyId)
            ->get();
        if (request()->ajax()) {

            //$data = $Select_db->get();
            return datatables()->of($Select_db)->make(true);
        }

        //$data = $Select_db->get();


        return view('Users.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(!UserAccessController::check_access(3, 'write')){
           return redirect('/no_access');
        }

        $users_role = DB::select('SELECT * from users_role');
        $lkp_active = DB::select('SELECT * from lkp_active');
        return view('Users.create')->with(compact('users_role'))->with(compact('lkp_active'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        
        $this->validate($request, [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:6'],


        ]);


        $picture = null;
        $Users = new User;
        $Users->name = $request->input('name');
        $Users->lname = $request->input('lname');
        $Users->email = $request->input('email');
        $Users->phone = $request->input('phone');
        $Users->role_id = $request->input('role_id');
        $Users->active_id = $request->input('active_id');
        $Users->password = bcrypt($request->input('password'));
        $Users->companyId = Auth::user()->companyId;
         if ($request->hasFile('ProfileImage')) {
    
                $file      = $request->file('ProfileImage');
                $filename  = $file->getClientOriginalName();
                $extension = $file->getClientOriginalExtension();
                $picture =  $filename.'_'.date('YmdHi').'.'.$extension;
                $file->move(public_path('user_images'), $picture);
            }

        $Users->profileImage =  $picture; 
        $Users->save();

        return redirect('/Users')->with('success', 'Done successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(!UserAccessController::check_access(2, 'read')){
           return redirect('/no_access');
        }

        $Select_db = DB::table('users')
            ->select('users.id as id', 'name', 'lname', 'phone', 'email', 'password','active_id', 'users.companyId as user_company', 'active', 'role_id', 'role_name',
                'users.created_at', 'users.updated_at', 'users.profileImage')
            ->leftJoin('lkp_active', 'users.active_id', '=', 'lkp_active.id')
            ->leftJoin('users_role', 'users.role_id', '=', 'users_role.id')
            ->where('users.companyId', Auth::user()->companyId)
            ->where('users.id', $id);
        $Users = $Select_db->first(); 

        return view('Users.show')->with('Users', $Users);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(!UserAccessController::check_access(2, 'write')){
           return redirect('/no_access');
        }

        $users_role = DB::select('SELECT * from users_role');
        $lkp_active = DB::select('SELECT * from lkp_active');
        $Users = DB::select(DB::raw('SELECT * from users where users.companyId=' . Auth::user()->companyId . ' and id=' . $id))[0];
        return view('Users.edit')->with('Users', $Users)->with(compact('users_role'))->with(compact('lkp_active'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //'password' => ['required', 'string', 'min:8', 'confirmed'],
        $this->validate($request, [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255',],

        ]);

        
        //$Users = User::find($id);
        $picture = null; 
        $Users = User::where('id', $id)->where('companyId', Auth::user()->companyId)->first();
        $Users->name = $request->input('name');
        $Users->lname = $request->input('lname');
        $Users->email = $request->input('email');
        $Users->phone = $request->input('phone');
        $Users->role_id = $request->input('role_id');
        $Users->active_id = $request->input('active_id');
        $Users->companyId = Auth::user()->companyId;
        //$Users->companyId = $request->input('companyId');

        if ($request->hasFile('ProfileImage')) {
                            //Remove existing image from file directory

        if(File::exists(public_path('user_images/'.$Users->profileImage))){
            
            File::delete(public_path('user_images/'.$Users->profileImage));
        }
    
                $file      = $request->file('ProfileImage');
                $filename  = $file->getClientOriginalName();
                $extension = $file->getClientOriginalExtension();
                $picture =  $filename.'_'.date('YmdHi').'.'.$extension;
                $file->move(public_path('user_images'), $picture);
                $Users->profileImage =  $picture;    
        }

        if($request->input('password') !=""){
            $Users->password = bcrypt($request->input('password'));
        }
        
        $Users->save();

        return redirect('/Users')->with('success', 'Done successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(!UserAccessController::check_access(2, 'write')){
           return redirect('/no_access');
        }
        
        $Users = User::where('id', $id)->where('companyId', Auth::user()->companyId)->first();
        // if(auth()->user()->id !== $Users->user_id){
        //    return redirect('/Users')->with('error','Unauthorized');
        // }

        if ($Users->logo != 'noImage.jpg') {
            Storage::delete('public/app/storage' . $Users->logo);

        }

        $Users->delete();

        return redirect('/Users')->with('success', 'Done successfully');
    }

    public function ResetPass($id)
    {

        $Users = DB::select('SELECT name from users where users.companyId=' . Auth::user()->companyId . ' and id=' . $id)[0];
        return view('Users.ResetPass')->with(compact('Users'))->with(compact('id'));
    }

    public function SaveResetPass(Request $request)
    {
        $Users = User::where('id', $request->input('id'))->where('companyId', Auth::user()->companyId)->first();
        $Users->password = bcrypt($request->input('password'));
        $Users->save();

        return redirect('/Users')->with('success', 'Done successfully');
    }
}
